//# sourceURL=bridge_out.js

/**
 * MobileCallback VTable to allow other scripts to override callbacks
 */
window.MobileCallbackExt = {
    __bind: function() {
        arguments[0].apply(null, Array.prototype.slice.call(arguments, 1));
    },
    __run: function() {
        var name = arguments[0];
        var args = Array.from(arguments);
        args[0] = MobileCallback[name].bind(MobileCallback);
        MobileCallbackExt[name].apply(null, args);
    }
};
for (key in MobileCallback) {
    MobileCallbackExt[key] = MobileCallbackExt.__bind;
}

window.SDKDelegate = {
  initAd: function(contextId, type, payload) {
    NativeMediation.initAd(contextId, type, payload);
  },
  startAd: function(contextId) {
    NativeMediation.startAd(contextId);
  },
  pauseAd: function(contextId) {
    NativeMediation.pauseAd(contextId);
  },
  resumeAd: function(contextId) {
    NativeMediation.resumeAd(contextId);
  },
  stopAd: function(contextId) {
    NativeMediation.stopAd(contextId);
  },
  setAdVolume: function(contextId, payload) {
    NativeMediation.setAdVolume(contextId, JSON.stringify(payload));
  },
  getAdVolume: function(contextId) {
    return NativeMediation.getAdVolume(contextId);
  },
  getAdSkippableState: function(contextId) {
    return NativeMediation.getAdSkippableState(contextId);
  },
  getAdWidth: function(contextId) {
    return NativeMediation.getAdWidth(contextId);
  },
  getAdHeight: function(contextId) {
    return NativeMediation.getAdHeight(contextId);
  },
  getAdRemainingTime: function(contextId) {
    return NativeMediation.getAdRemainingTime(contextId);
  },
  getDuration: function(contextId) {
    return NativeMediation.getDuration(contextId);
  }
};

window.sdkCtx = 1;
var eventCallbacks = {};
window.eventDispatcher = {
  addListener: function(context, callback) {
    eventCallbacks[context] = callback;
  },
  removeListener: function(context) {
    if(eventCallbacks[context])
      delete eventCallbacks[context];
  },
  dispatch: function(context, event, data) {
    if(eventCallbacks[context])
      eventCallbacks[context](event, data);
  }
};

(function (window) {
  function sdkDebugApi() {
    var s = this;
    s.debug = false;
    s.queue = [];

    s.setDebug = function(debug) {
      s.debug = debug;
    }
    s.pushMessage = function(name, value) {
      if (!s.debug) {
        return;
      }
      s.queue.push([name, value]); // push pair
    }
    s.commitMessages = function() {
      if (!s.debug) {
        return;
      }
      var pushed = false;
      while(s.queue.length > 0){
        var pair = s.queue.shift();
        MobileCallback.onDebugItem(pair[0], pair[1]);
        pushed = true;
      }
      if (pushed) {
        MobileCallback.onDebugItemsEnded();
      }
    }
    s.acceptImpression = function(imp) {
      if (!s.debug || !imp) return;

      s.pushMessage("asid", imp.asid);
      s.pushMessage("mt", imp.mt);
      var tag = imp.tagInfo;
      if (tag) {
        s.pushMessage("url", unescape(tag.url));
      }
      s.pushMessage("videoUrl", unescape(imp.videoUrl));
      s.commitMessages();
    }
  }

  window.avDebugApi = new sdkDebugApi();
})(window);

(function (window) {

  function sdkApiProto() {
    var t = this;
    t.dummyDiv = document.createElement('div');
    t.dummyDiv.classList.add("avp-hidden"); // to fix blackscreen for content
    t.dummyDiv.style.cssText = 'position:absolute;z-index: 9999;width:1px;height:1px;';
    document.body.appendChild(t.dummyDiv);

    t.getReliableWidth = function() {
      return document.body.clientWidth || window.innerWidth;
    }
    t.getReliableHeight = function() {
      return document.body.clientHeight || window.innerHeight;
    }

    t.setViewability = function(viewability) {
      if (player && player.setViewability) {
        player.setViewability(viewability);
      }
    }

    t.unmute = function() {
      if (player) {
        player.unmute();
      }
    }
    t.mute = function() {
      if (player) {
        player.mute()
      }
    }
    t.setVolume = function(level) {
      if (player && player.setVolume) {
        player.setVolume(level);
      }
    }
    t.isMuted = function() {
      if (player) {
        return player.getAdVolume() == 0;
      }
      return false;
    }
    t.getVolume = function() {
      if (player) {
        return player.getVolume();
      }
      return 0;
    }
    t.pause = function() {
      if (player) {
        player.pause();
      }
    }
    t.resume = function() {
      if (player) {
        player.resume();
      }
    }
    t.close = function() {
      if (player) {
        player.close();
        MobileCallbackExt.__run("onClose"); // cant trust the callback, need to handle this ourselves
      }
    }
    t.nextContent = function() {
      if (player) {
        player.nextContent();
      }
    }
    t.prevContent = function() {
      if (player) {
        player.prevContent();
      }
    }
    t.setSize = function(width, height) {
      if (player) {
        console.log("setSize " + width +"x" + height);
        player.resize(width, height);
      } else {
        console.log("setSize " + width +"x" + height + " (no player)");
      }
    }
    t.startAd = function() {
      if (player) {
        player.startAd();
      }
    }
    t.skipAd = function() {
      if (player) {
        player.skip();
      }
    }
    t.getReadyAds = function() {
      if (player) {
        return JSON.stringify(player.getReadyAds());
      }
      return "no player";
    }
    t.pauseWaterfall = function() {
      if (player) {
        player.setWaterfallState(false, false);
      }
    }
    t.getAdRemainingTime = function() {
        if (player) {
            return player.getAdRemainingTime();
        }
        return 0;
    }
    t.resumeWaterfall = function() {
      if (player) {
        player.setWaterfallState(true, true);
      }
    }
    t.resize = function() {
      if (player) {
        player.resize(t.getReliableWidth(), t.getReliableHeight());
      }
    }
    t.changeGui = function(showSkip, showSound, showPlay, showFullscreen) {
        // noop for out-stream
    }
    t.hidePlaylist = function() {
        // noop for out-stream
    }
    t.setFullscreenState = function(isFullscreen) {
        if (player) {
            player.setFullscreenState(isFullscreen);
        }
    }

    window.addEventListener("click", function(event) {
        MobileCallbackExt.__run("onPlayerClicked");
    });

    var scriptId = window.sdkConfig.scriptId;
    window.aniviewRenderer = {units:{}};
    window.aniviewRenderer.units[scriptId] = {
      preparePlayer: function(p) {
        player = p;

        p.on("FullScreenRequest", function(){
            MobileCallbackExt.__run("onFullScreenRequest");
        });

        p.on("ContentFullScreenRequest", function(){
            MobileCallbackExt.__run("onFullScreenRequest");
        });

        p.on("onError", function(res){
            MobileCallbackExt.__run("onError", JSON.stringify(res));
        });

        p.on("Inventory", function(data){
            MobileCallbackExt.__run("onInventory");
        });

        p.on("AdReady", function(){
            MobileCallbackExt.__run("onAdReady");
        });

        p.on("AdLoaded", function(){
            MobileCallbackExt.__run("onLoad");
        });

        p.on("AdImpression", function(imp){
            MobileCallbackExt.__run("onPlay", JSON.stringify(imp));
            window.avDebugApi.acceptImpression(imp);
        });

        p.on("AdViewableImpression", function(){
            MobileCallbackExt.__run("onViewableImpression");
        });

        p.on("onContentPlay", function(){
            MobileCallbackExt.__run("onContentPlay");
        });

        p.on("AdVideoFirstQuartile", function(){
            MobileCallbackExt.__run("onPlay25");
        });

        p.on("AdVideoMidpoint", function(){
            MobileCallbackExt.__run("onPlay50");
        });

        p.on("AdVideoThirdQuartile", function(){
            MobileCallbackExt.__run("onPlay75");
        });

        p.on("AdVideoComplete", function(data) {
            MobileCallbackExt.__run("onPlay100", data.showCompanion);
        });

        p.on("AdClickThru", function(data){
            MobileCallbackExt.__run("onClickThrough", JSON.stringify(data));
        });

        p.on("AdSkipped", function(data){
            MobileCallbackExt.__run("onSkip", data.showCompanion);
        });

        p.on("AdSkippableStateChange", function(){
            MobileCallbackExt.__run("onSkipAvailable");
        });

        p.on("AdClosed", function(){
//          MobileCallback.onClose(); // ignore for ad
        });

        p.on("AdPaused", function(){
            MobileCallbackExt.__run("onAdPaused");
        });

        p.on("AdPlaying", function(){
            MobileCallbackExt.__run("onAdPlaying");
        });

        p.on("ContentPauseClicked", function(){
            MobileCallbackExt.__run("onContentPauseClicked");
        });

        p.on("ContentPlayClicked", function(){
            MobileCallbackExt.__run("onContentPlayClicked");
        });

        p.on("ContentPaused", function(){
            MobileCallbackExt.__run("onContentPaused");
        });

        p.on("ContentPlaying", function(){
            MobileCallbackExt.__run("onContentPlaying");
        });

        p.on("AdVolumeChange", function(){
            MobileCallbackExt.__run("onAdVolumeChanged", player.getAdVolume());
        });

        p.on("AdDurationChange", function() {
            MobileCallbackExt.__run("onAdDurationChanged", player.getAdDuration());
        });

        p.on("ContentVolumeChange", function(){
            MobileCallbackExt.__run("onContentVolumeChanged", player.getVolume());
        });

        p.on("onMute", function(){
            MobileCallbackExt.__run("onMute");
        });

        p.on("onUnmute", function(){
            MobileCallbackExt.__run("onUnmute", p.getVolume());
        });

        p.on("AdError", function(err){
          if (err && err.errorlimit) {
            MobileCallbackExt.__run("onAdFetchingCompleted");
          } else {
            MobileCallbackExt.__run("onAdError", JSON.stringify(err));
          }
        });

        p.on("ContentVideoStart", function(){
            MobileCallbackExt.__run("onContentStarted");
        });

        p.on("ContentVideoFirstQuartile", function(){
            MobileCallbackExt.__run("onContentPlay25");
        });

        p.on("ContentVideoMidpoint", function(){
            MobileCallbackExt.__run("onContentPlay50");
        });

        p.on("ContentVideoThirdQuartile", function(){
            MobileCallbackExt.__run("onContentPlay75");
        });

        p.on("ContentVideoComplete", function(){
            MobileCallbackExt.__run("onContentPlay100");
        });

        p.on("ContentTimeChange", function(event, data){
            MobileCallbackExt.__run("onContentTimeChange", data.currentTime, player.getContentDuration());
        });

        p.on("WaterfallEnd", function(){
            MobileCallbackExt.__run("onWaterfallEnd");
        });

        console.log("preparePlayer: finished");
        MobileCallback.onPlayerReady();
      },
      prepareConfig: function(c) {
        c.inappSdk = true;
        console.log("sdkConfig: " + JSON.stringify(window.sdkConfig));

        console.log("expected size set to [" +window.sdkConfig.expectedWidth +"x" +window.sdkConfig.expectedHeight +"]");
        c.width = window.sdkConfig.expectedWidth || t.getReliableWidth();
        c.height = window.sdkConfig.expectedHeight || t.getReliableHeight();
        c.floating = undefined;
        c.adLabel = undefined;
        c.sticky = undefined;
        c.posSelector = "";
        c.aniBoxCSS = "''";
        c.posDfp1x1 = false;
        c.noAdsOnContentPause = true;
        c.closeButton = false;
        c.hideInitPreloader = false;
        c.playOnView = false;
        c.pauseOnUnseen = false;
        c.nativeVideo = true;
        c.autoPlay = true;
        c.showPos = true;
        c.imasdkmode = 1;
        c.initialvi = 0;
        c.disableom = false;
        c.tgt = window.sdkConfig.tgt;

        if(window.sdkConfig.ref1) {
          c.ref1 = (c.ref1 || "") + "&" + window.sdkConfig.ref1;
        }
        if(window.debug) {
          window.avDebugApi.setDebug(window.debug);
        }

        if(window.sdkConfig.channelId) {
           console.log("overriding channelId: " +window.sdkConfig.channelId);
           c.channelId = window.sdkConfig.channelId;
        }

//        c.baseJsUrl="https://storage.googleapis.com/player-cd/6.2.219/";
//        c.publisherId="55b78633181f4603178b4568";
//        c.waterfall = function(callback) {
//            var waterfall = {
//              data: {
//                tags: [{
//                  asid: 4,
//                  priority: 1,
//                  type: "pl",
//                  platform: 11,
//                  template: JSON.stringify({
//                    "configId": "CONFIG_ID",
//                    "adUnitId": "/22466671215/ca-pub-6346866704322274-tag/webm_test/serhii_test_example",
//                    "sizes": [
//                      {
//                        "width": 300,
//                        "height": 250
//                      }
//                    ],
//                    "customTargeting": {
//                      "key1": "value1",
//                      "key2": "value2"
//                    }
//                  })
//                }],
//              }
//            };
//            callback(waterfall, "cdn.aniview.com");
//          }

        console.log("prepareConfig: finished");
      }
    };
  }

  window.avSdkApi = new sdkApiProto();
})(window);
